@@ -33,21 +33,7 @@ sub _build_data {
 
 
 has psgi => (
-    is     => 'rw',
-    isa    => sub {
-        my $psgi = shift;
-
-        die 'The psgi attribute must must be a valid PSGI filepath or code '.
-            'reference' if !$psgi && ('CODE' eq ref($psgi) xor -f $psgi);
-    },
-    coerce => sub {
-        my $psgi = shift;
-
-        # return psgi
-        return $psgi if (ref $psgi) =~ /Plack::Test::/; # very trusting
-        return Plack::Test->create($psgi) if 'CODE' eq ref $psgi;
-        return Plack::Test->create(Plack::Util::load_psgi($psgi));
-    }
+    is   => 'rw',
 );
 
 
@@ -223,7 +209,7 @@ Plack::Test::Simple::Transaction - PSGI Automated Application Testing Layer
 
 =head1 VERSION
 
-version 0.000007
+version 0.000008
 
 =head1 SYNOPSIS
 
@@ -261,8 +247,7 @@ response body.
 =head2 psgi
 
 The psgi attribute contains a coderef containing the PSGI compliant application
-code. If this value is a string containing the path to the psgi file, the
-application code will be coerced.
+code.
 
 =head2 request
 
